# Filecoin Mechanical Twin

Mechanistic model for the Filecoin Economy.


## Prerequisites

```
numpy>=1.23.1
pandas>=1.4.3
requests>=2.28.1
matplotlib>=3.5.2
seaborn>=0.11.2
```

## Installing

This package is available on PyPI and thus can be directly installed with pip:

```
pip install mechafil
```

Alternatively, this package can be installed from source by cloning this repository and installing it manually with the command:

```
python setup.py install
```

## Usage

TBD


## References

TBD